js.jqueryui_tagit
*****************

Introduction
============

This library packages `Tag-it!`_ for `fanstatic`_.

.. _`fanstatic`: http://fanstatic.org
.. _`Tag-it!`: http://aehlke.github.com/tag-it/

This requires integration between your web framework and ``fanstatic``,
and making sure that the original resources (shipped in the ``resources``
directory in ``js.jqueryui_tagit``) are published to some URL.

